@@ -10,7 +10,7 @@ class DatabaseDAO(DAOBase):
     
     def get_by_tenant(self, tenant):
         sql = """
-            select host, porta, nome
+            select host, porta, nome, "user", password
             from multibanco.database
             where tenant = :tenant;
         """
