@@ -1,3 +1,5 @@
+
+from cryptography.fernet import Fernet
 from functools import wraps
 from flask import g, request
 
@@ -5,7 +7,7 @@ from nsj_gcf_utils.rest_error_util import format_json_error
 
 from nsj_multi_database_lib.exception import ParameterNotFound
 from nsj_multi_database_lib.injector_factory import InjectorFactory
-from nsj_multi_database_lib.settings import get_logger
+from nsj_multi_database_lib.settings import get_logger, get_crypt_key
 
 
 def multi_database():
@@ -41,14 +43,33 @@ def multi_database():
                         "password": None
                     }
 
-                with InjectorFactory(use_external_db_with_default_credentials=True) as factory:
-                    usuario_dao = factory.usuario_dao()
+                    # Verificando se o usuário e senha estão no BD
+                    user = None
+                    password = None
+                    if database["user"] is not None and database["password"] is not None:
+                        fernet = Fernet(get_crypt_key())
 
-                    usuario = usuario_dao.get_by_email(g.profile["email"])
+                        # Decypt user
+                        user = database["user"].encode()
+                        user = fernet.decrypt(user).decode()
 
-                    g.external_database["user"] = __get_db_username(
-                        g.external_database["name"], usuario["login"])
-                    g.external_database["password"] = usuario["senha"]
+                        # Decypt user
+                        password = database["password"].encode()
+                        password = fernet.decrypt(password).decode()
+                    
+                if user is None or password is None:
+                    with InjectorFactory(use_external_db_with_default_credentials=True) as factory:
+                        usuario_dao = factory.usuario_dao()
+
+                        usuario = usuario_dao.get_by_email(g.profile["email"])
+
+                        user = __get_db_username(
+                            g.external_database["name"], usuario["login"])
+                        password = usuario["senha"]
+                
+                # Gravando usuario e senha na variável g do Flask
+                g.external_database["user"] = user
+                g.external_database["password"] = password
 
                 return func(*args, **kwargs)
             except ParameterNotFound as e:
