@@ -26,7 +26,7 @@ class DatabaseEntity(EntityBase):
         self.tenant: str = None 
 
     def get_table_name(self) -> str:
-        return "config.database"
+        return "multibanco.database"
 
     def get_default_order_fields(self) -> List[str]:
         return ['id']
